OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Tasks" : "Задачи",
    "Personal" : "Личен",
    "{actor} created calendar {calendar}" : "{actor} направи календар {calendar}",
    "You created calendar {calendar}" : "Създадохте календара {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} изтри календар {calendar}",
    "You deleted calendar {calendar}" : "Изтрихте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} обнови календар {calendar}",
    "You updated calendar {calendar}" : "Обновихте календар {calendar}",
    "{actor} restored calendar {calendar}" : "{actor} възстанови календар {calendar}",
    "You restored calendar {calendar}" : "Вие възстановихте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Споделихте календара {calendar} с публична връзка",
    "You removed public link for calendar {calendar}" : "Премахнахте публична връзка към календара {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} сподели календара {calendar} с вас",
    "You shared calendar {calendar} with {user}" : "Споделихте календара {calendar} с {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} сподели календар {calendar} с {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} отказа споделянето на календара {calendar} с вас",
    "You unshared calendar {calendar} from {user}" : "Отказахте споделянето на календара {calendar} от {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} отказа споделяне на календар {calendar} от {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} отказа споделяне на календар {calendar} от себеси",
    "You shared calendar {calendar} with group {group}" : "Споделихте календара {calendar} с група {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} сподели календар {calendar} с група {group}",
    "You unshared calendar {calendar} from group {group}" : "Отказахте споделянето на календара {calendar} от група {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} отказа споделяне с календар {calendar} от група {group}",
    "Untitled event" : "Събитие без заглавие",
    "{actor} created event {event} in calendar {calendar}" : "{actor} създаде събитие {event} в календар {calendar}",
    "You created event {event} in calendar {calendar}" : "Създадохте събитие {event} в календар {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} изтри събитие {event} от календар {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Изтрихте събитие {event} от календар {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} обнови събитие {event} в календар {calendar}",
    "You updated event {event} in calendar {calendar}" : "Обновихте събитие {event} в календар {calendar}",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} премести събитие {event} от календар {sourceCalendar} в календар {targetCalendar}",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "Преместихте събитие {event} от календар {sourceCalendar} в календар {targetCalendar}",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} възстанови събитие {event} от календар {calendar}",
    "You restored event {event} of calendar {calendar}" : "Вие възстановихте събитие {event} от календар {calendar}",
    "Busy" : "Зает",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} създаде задача {todo} в списък {calendar}",
    "You created to-do {todo} in list {calendar}" : "Създадохте задача {todo} в списък {calendar}",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} изтри задача {todo} от списък {calendar}",
    "You deleted to-do {todo} from list {calendar}" : "Изтрихте задача {todo} от списък {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} актуализира задача {todo} в списък {calendar}",
    "You updated to-do {todo} in list {calendar}" : "Актуализирахте задачи {todo} в списъка {calendar}",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} разреши задача {todo} в списък {calendar}",
    "You solved to-do {todo} in list {calendar}" : "Разрешихте задача {todo} в списък {calendar}",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} отвори отново задача {todo} в списък {calendar}",
    "You reopened to-do {todo} in list {calendar}" : "Отворихте отново задача {todo} в списък {calendar}",
    "{actor} moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "{actor} премести задача {todo} от списък {sourceCalendar} в списък {targetCalendar}",
    "You moved to-do {todo} from list {sourceCalendar} to list {targetCalendar}" : "Преместихте задача {todo} от списък {sourceCalendar} в списък {targetCalendar}",
    "Calendar, contacts and tasks" : "Календар, контакти и задачи",
    "A <strong>calendar</strong> was modified" : "Промяна на <strong>календар</strong>",
    "A calendar <strong>event</strong> was modified" : "Промяна на календарно <strong>събитие</strong>",
    "A calendar <strong>to-do</strong> was modified" : "<strong>задача</strong>от календар беше променена",
    "Contact birthdays" : "Рождени дни на контакти",
    "Death of %s" : "Смърт на %s",
    "Untitled calendar" : "Нов календар",
    "Calendar:" : "Календар:",
    "Date:" : "Дата:",
    "Where:" : "Къде:",
    "Description:" : "Описание:",
    "_%n year_::_%n years_" : ["%n години","%n години"],
    "_%n month_::_%n months_" : ["%n месеци","%n месеци"],
    "_%n day_::_%n days_" : ["%n  дни","%n дни"],
    "_%n hour_::_%n hours_" : ["%n часове","%n часа"],
    "_%n minute_::_%n minutes_" : ["%n минути","%n минути"],
    "%s (in %s)" : "%s (в %s)",
    "%s (%s ago)" : "%s (преди %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Дата: %s",
    "Description: %s" : "Описание: %s",
    "Where: %s" : "Къде: %s",
    "%1$s via %2$s" : "%1$s чрез %2$s",
    "Cancelled: %1$s" : "Отказан: %1$s",
    "\"%1$s\" has been canceled" : "„%1$s“ е отказано",
    "Re: %1$s" : "Re: %1$s",
    "%1$s has accepted your invitation" : "%1$s е приел поканата ви",
    "%1$s has tentatively accepted your invitation" : "%1$s е приел поканата ви условно",
    "%1$s has declined your invitation" : "%1$s е отказал поканата ви",
    "%1$s has responded to your invitation" : "%1$s отговори/ха на вашата покана",
    "Invitation updated: %1$s" : "Поканата е актуализирана: %1$s",
    "%1$s updated the event \"%2$s\"" : "%1$s актуализира събитието „%2$s“",
    "Invitation: %1$s" : "Покана: %1$s",
    "%1$s would like to invite you to \"%2$s\"" : "%1$s желае да ви покани на „%2$s“",
    "Organizer:" : "Organizer/организатор/:",
    "Attendees:" : "Участници:",
    "Title:" : "Заглавие:",
    "Location:" : "Местоположение:",
    "Link:" : "Връзка:",
    "Accept" : "Приемане",
    "Decline" : "Отхвърляне",
    "More options …" : "Още опции ...",
    "More options at %s" : "Още опции при %s",
    "Monday" : "Понеделник",
    "Tuesday" : "Вторник",
    "Wednesday" : "Сряда",
    "Thursday" : "Четвъртък",
    "Friday" : "Петък",
    "Saturday" : "Събота",
    "Sunday" : "Неделя",
    "January" : "Януари",
    "February" : "Февруари",
    "March" : "Март",
    "April" : "Април",
    "May" : "Май",
    "June" : "Юни",
    "July" : "Юли",
    "August" : "Август",
    "September" : "Септември",
    "October" : "Октомври",
    "November" : "Ноември",
    "December" : "Декември",
    "First" : "Първо",
    "Last" : "Последно",
    "Contacts" : "Контакти",
    "{actor} created address book {addressbook}" : "{actor} създаде адресна книга {addressbook}",
    "You created address book {addressbook}" : "Вие създадохте адресна книга {addressbook}",
    "{actor} deleted address book {addressbook}" : "{actor} изтри адресна книга {addressbook}",
    "You deleted address book {addressbook}" : "Вие изтрихте адресна книга {addressbook}",
    "{actor} updated address book {addressbook}" : "{actor} актуализира адресна книга {addressbook}",
    "You updated address book {addressbook}" : "Вие актуализирахте адресна книга {addressbook}",
    "{actor} shared address book {addressbook} with you" : "{actor} сподели адресна книга {addressbook} с вас",
    "You shared address book {addressbook} with {user}" : "Вие споделихте адресна книга {addressbook} с {user}",
    "{actor} shared address book {addressbook} with {user}" : "{actor} сподели адресна книга {addressbook} с {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} отмени споделяне на адресна книга {addressbook} от вас",
    "You unshared address book {addressbook} from {user}" : "Вие отменихте споделяне на адресна книга {addressbook} от {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} отмени споделяне на адресна книга {addressbook} от {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} отмениха споделяне на адресна книга {addressbook} от самите тях ",
    "You shared address book {addressbook} with group {group}" : "Вие споделихте адресна книга {addressbook} с група {group}",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} сподели адресна книга {addressbook} с група {group}",
    "You unshared address book {addressbook} from group {group}" : "Вие отменихте споделяне на адресна книга {addressbook} от група {group}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} отмени споделяне на адресна книга {addressbook} от група {group}",
    "{actor} created contact {card} in address book {addressbook}" : "{actor} създаде контакт {card} в адресна книга {addressbook}",
    "You created contact {card} in address book {addressbook}" : "Вие създадохте контакт {card} в адресна книга {addressbook}",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} изтри контакт {card} от адресна книга {addressbook}",
    "You deleted contact {card} from address book {addressbook}" : "Вие изтрихте контакт {card} от адресна книга {addressbook}",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} актуализира контакт {card} в адресна книга  {addressbook}",
    "You updated contact {card} in address book {addressbook}" : "Вие актуализирахте контакт {card} в адресна книга {addressbook}",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "Един  <strong>contact</strong> или <strong>address book</strong> са променени",
    "File is not updatable: %1$s" : "Файлът не подлежи на актуализиране: %1$s",
    "Could not write to final file, canceled by hook" : "Не можа да се запише в крайния файл, анулирано от кука",
    "Could not write file contents" : "Съдържанието на файла не можа да се запише",
    "_%n byte_::_%n bytes_" : ["%n  байта","%n байта"],
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "Грешка при копирането на файла в целево местоположение (копирано: %1$s, очакван размер на файла: %2$s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "Очакван размер на файл от %1$s, но прочетени (от Nextcloud клиент) и записани (в хранилище на Nextcloud) %2$s. Това може да бъде, както мрежов проблем от страна на изпращача, така и проблем със записването в хранилище от страна на сървъра.",
    "Could not rename part file to final file, canceled by hook" : "Не можа да се преименува частичен файл в краен файл, анулиран е от кука",
    "Could not rename part file to final file" : "Не можа да се преименува частичен файл в краен файл",
    "Failed to check file size: %1$s" : "Неуспешна проверка на размера на файла: %1$s",
    "Encryption not ready: %1$s" : "Криптирането не е готово: %1$s",
    "Failed to open file: %1$s" : "Неуспешно отваряне на файл: %1$s",
    "Failed to unlink: %1$s" : "Неуспешно прекратяване на връзката: %1$s",
    "Failed to write file contents: %1$s" : "Неуспешно записване на съдържанието на файла: %1$s",
    "File not found: %1$s" : "Файлът не е намерен: %1$s",
    "System is in maintenance mode." : "Системата е в режим на поддръжка.",
    "Upgrade needed" : "Нужно е обновяване",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Вашият%s, трябва да бъде конфигуриран да използва HTTPS, за да използва CalDAV и CardDAV с iOS/macOS.",
    "Configures a CalDAV account" : "Конфигурира профил в CalDAV",
    "Configures a CardDAV account" : "Конфигурира профил в CalDAV",
    "Events" : "Събития",
    "Untitled task" : "Задача без заглавие",
    "Completed on %s" : "Завършен на %s",
    "Due on %s by %s" : "Краен срок на %s от %s",
    "Due on %s" : "Краен срок на %s",
    "WebDAV endpoint" : "WebDAV крайна точка",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Вашият уеб сървър все още не е удачно настроен да позволява синхронизация на файлове, защото WebDAV интерфейсът не работи.",
    "Migrated calendar (%1$s)" : "Мигриран календар (%1$s)",
    "Calendars including events, details and attendees" : "Календари, включително събития, подробности и участници",
    "Contacts and groups" : "Контакти и групи",
    "WebDAV" : "WebDAV",
    "First day" : "Първи ден",
    "Save" : "Запазване",
    "Time zone:" : "Часова зона",
    "to" : "до",
    "Delete slot" : "Изтриване на слот",
    "No working hours set" : "Няма зададено работно време",
    "Add slot" : "Добавяне на слот",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Автоматично задаване на потребителският статус на „Не безпокойте“ извън достъпността, за заглушаване на всички известия.",
    "Failed to load availability" : "Неуспешно зареждане на наличност",
    "Saved availability" : "Запазена наличност",
    "Failed to save availability" : "Неуспешно записване на наличност",
    "Availability" : "Наличност",
    "Calendar server" : "Сървър на календар",
    "Send invitations to attendees" : "Изпращане на покани до участниците",
    "Automatically generate a birthday calendar" : "Автоматично генериране на календар с рождени дни.",
    "Birthday calendars will be generated by a background job." : "Календарите с рождени дни се генерират от background job.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Това е причината поради която те не се появяват веднага, след като включите опцията.",
    "Send notifications for events" : "Изпращане на известия за събития",
    "Notifications are sent via background jobs, so these must occur often enough." : "Известията се изпращат чрез фонови задания, така че те трябва да се случват достатъчно често.",
    "Send reminder notifications to calendar sharees as well" : "Изпращане на известия за напомняния и до споделящите календар",
    "Reminders are always sent to organizers and attendees." : "Напомнянията винаги се изпращат до организаторите и присъстващите.",
    "Enable notifications for events via push" : "Активиране на известията за събития чрез push",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Също така инсталирайте приложението {calendarappstoreopen}Календар{linkclose} или {calendardocopen}, свържете вашия настолен компютър и мобилен телефон за синхронизиране ↗{linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Моля, уверете се, че сте настроили правилно {emailopen} имейл сървъра{linkclose}.",
    "There was an error updating your attendance status." : "Възникна грешка при актуализиране на състоянието на присъствието Ви.",
    "Please contact the organizer directly." : "Моля, свържете се директно с организатора.",
    "Are you accepting the invitation?" : "Приемате ли поканата?",
    "Tentative" : "Несигурно",
    "Your attendance was updated successfully." : "Вашето присъствие е актуализирано успешно.",
    "To-dos" : "Задачи за изпълнение",
    "Time:" : "Час:",
    "Could not open file" : "Файлът не можа да се отвори",
    "Invalid chunk name" : "Невалидно име на блок",
    "Could not rename part file assembled from chunks" : "Не можа да се преименува частичен файл, сглобен от блок",
    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Ако конфигурирате работното си време, другите потребители ще виждат кога сте извън офиса, при резервиране на среща."
},
"nplurals=2; plural=(n != 1);");
